use strict;
use warnings;
package Module::Build::JSONMETA;
our $VERSION = '1.000';

=head1 NAME

Module::Build::JSONMETA - (unimplemented) write META.yml with JSON syntax

=cut

die "not yet implemented";

1;
